==> tax-device-contract-model-1.4-20210301.082130-90-sources.jar: com/xforceplus/micro/tax/device/contract/model/HeartBeatClientInfo.java <==
package com.xforceplus.micro.tax.device.contract.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.io.Serializable;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * 客户端信息
 */
@ApiModel(description = "客户端信息")

@JsonInclude(NON_NULL)
public class HeartBeatClientInfo implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("version")
  private String version = null;

  @JsonProperty("cloudVender")
  private String cloudVender = null;

  @JsonProperty("mKind")
  private String mKind = null;

  @JsonProperty("vendorType")
  private String vendorType = null;

  @JsonIgnore
  public HeartBeatClientInfo version(String version) {
    this.version = version;
    return this;
  }

   /**
   * 客户端版本
   * @return version
  **/


  @ApiModelProperty(value = "客户端版本")
  public String getVersion() {
    return version;
  }

  public void setVersion(String version) {
    this.version = version;
  }

  @JsonIgnore
  public HeartBeatClientInfo cloudVender(String cloudVender) {
    this.cloudVender = cloudVender;
    return this;
  }

   /**
   * 云服务商标识[ac-阿里云提供服务 tc-腾讯云提供服务]
   * @return cloudVender
  **/


  @ApiModelProperty(value = "云服务商标识[ac-阿里云提供服务 tc-腾讯云提供服务]")
  public String getCloudVender() {
    return cloudVender;
  }

  public void setCloudVender(String cloudVender) {
    this.cloudVender = cloudVender;
  }

  @JsonIgnore
  public HeartBeatClientInfo mKind(String mKind) {
    this.mKind = mKind;
    return this;
  }

   /**
   * 开票模式[A、B、A2、B2]
   * @return mKind
  **/


  @ApiModelProperty(value = "开票模式[A、B、A2、B2]")
  public String getMKind() {
    return mKind;
  }

  public void setMKind(String mKind) {
    this.mKind = mKind;
  }

  @JsonIgnore
  public HeartBeatClientInfo vendorType(String vendorType) {
    this.vendorType = vendorType;
    return this;
  }

   /**
   * 税盘类型[HX、BW、EK]
   * @return vendorType
  **/


  @ApiModelProperty(value = "税盘类型[HX、BW、EK]")
  public String getVendorType() {
    return vendorType;
  }

  public void setVendorType(String vendorType) {
    this.vendorType = vendorType;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    HeartBeatClientInfo heartBeatClientInfo = (HeartBeatClientInfo) o;
    return Objects.equals(this.version, heartBeatClientInfo.version) &&
        Objects.equals(this.cloudVender, heartBeatClientInfo.cloudVender) &&
        Objects.equals(this.mKind, heartBeatClientInfo.mKind) &&
        Objects.equals(this.vendorType, heartBeatClientInfo.vendorType);
  }

  @Override
  public int hashCode() {
    return Objects.hash(version, cloudVender, mKind, vendorType);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class HeartBeatClientInfo {\n");
    
    sb.append("    version: ").append(toIndentedString(version)).append("\n");
    sb.append("    cloudVender: ").append(toIndentedString(cloudVender)).append("\n");
    sb.append("    mKind: ").append(toIndentedString(mKind)).append("\n");
    sb.append("    vendorType: ").append(toIndentedString(vendorType)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}

==> tax-device-contract-model-1.7-20240613.095407-45-sources.jar: com/xforceplus/micro/tax/device/contract/model/HeartBeatClientInfo.java <==
package com.xforceplus.micro.tax.device.contract.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;
import com.fasterxml.jackson.annotation.JsonIgnore;
import java.io.Serializable;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * 客户端信息
 */
@ApiModel(description = "客户端信息")

@JsonInclude(NON_NULL)
public class HeartBeatClientInfo implements Serializable {
  private static final long serialVersionUID = 1L;

  @JsonProperty("version")
  private String version = null;

  @JsonProperty("cloudVender")
  private String cloudVender = null;

  @JsonProperty("mKind")
  private String mKind = null;

  @JsonProperty("vendorType")
  private String vendorType = null;

  @JsonProperty("terminalUn")
  private String terminalUn = null;

  @JsonIgnore
  public HeartBeatClientInfo version(String version) {
    this.version = version;
    return this;
  }

   /**
   * 客户端版本
   * @return version
  **/


  @ApiModelProperty(value = "客户端版本")
  public String getVersion() {
    return version;
  }

  public void setVersion(String version) {
    this.version = version;
  }

  @JsonIgnore
  public HeartBeatClientInfo cloudVender(String cloudVender) {
    this.cloudVender = cloudVender;
    return this;
  }

   /**
   * 云服务商标识[ac-阿里云提供服务 tc-腾讯云提供服务]
   * @return cloudVender
  **/


  @ApiModelProperty(value = "云服务商标识[ac-阿里云提供服务 tc-腾讯云提供服务]")
  public String getCloudVender() {
    return cloudVender;
  }

  public void setCloudVender(String cloudVender) {
    this.cloudVender = cloudVender;
  }

  @JsonIgnore
  public HeartBeatClientInfo mKind(String mKind) {
    this.mKind = mKind;
    return this;
  }

   /**
   * 开票模式[A、B、A2、B2]
   * @return mKind
  **/


  @ApiModelProperty(value = "开票模式[A、B、A2、B2]")
  public String getMKind() {
    return mKind;
  }

  public void setMKind(String mKind) {
    this.mKind = mKind;
  }

  @JsonIgnore
  public HeartBeatClientInfo vendorType(String vendorType) {
    this.vendorType = vendorType;
    return this;
  }

   /**
   * 税盘类型[HX、BW、EK]
   * @return vendorType
  **/


  @ApiModelProperty(value = "税盘类型[HX、BW、EK]")
  public String getVendorType() {
    return vendorType;
  }

  public void setVendorType(String vendorType) {
    this.vendorType = vendorType;
  }

  @JsonIgnore
  public HeartBeatClientInfo terminalUn(String terminalUn) {
    this.terminalUn = terminalUn;
    return this;
  }

   /**
   * 终端唯一码
   * @return terminalUn
  **/


  @ApiModelProperty(value = "终端唯一码")
  public String getTerminalUn() {
    return terminalUn;
  }

  public void setTerminalUn(String terminalUn) {
    this.terminalUn = terminalUn;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    HeartBeatClientInfo heartBeatClientInfo = (HeartBeatClientInfo) o;
    return Objects.equals(this.version, heartBeatClientInfo.version) &&
        Objects.equals(this.cloudVender, heartBeatClientInfo.cloudVender) &&
        Objects.equals(this.mKind, heartBeatClientInfo.mKind) &&
        Objects.equals(this.vendorType, heartBeatClientInfo.vendorType) &&
        Objects.equals(this.terminalUn, heartBeatClientInfo.terminalUn);
  }

  @Override
  public int hashCode() {
    return Objects.hash(version, cloudVender, mKind, vendorType, terminalUn);
  }


  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class HeartBeatClientInfo {\n");
    
    sb.append("    version: ").append(toIndentedString(version)).append("\n");
    sb.append("    cloudVender: ").append(toIndentedString(cloudVender)).append("\n");
    sb.append("    mKind: ").append(toIndentedString(mKind)).append("\n");
    sb.append("    vendorType: ").append(toIndentedString(vendorType)).append("\n");
    sb.append("    terminalUn: ").append(toIndentedString(terminalUn)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }

}
